import {Context, Next} from "koa";
import Router,{RouterContext} from "koa-router";
import { TagAccessor } from "../model/tag";
import { sendError } from "./error_handler";
import { createPermissionCheckMiddleware as PerCheck, Permission } from "../permission/permission";

export function getTagRounter(tagController: TagAccessor){
    let router = new Router();
    router.get("/",PerCheck(Permission.QueryContent),
        async (ctx: Context)=>{
            if(ctx.query["withCount"]){
                const c = await tagController.getAllTagCount();
                ctx.body = c;
            }
            else {
                const c = await tagController.getAllTagList();
                ctx.body = c;
            }
            ctx.type = "json";
        });
    router.get("/:tag_name", PerCheck(Permission.QueryContent),
        async (ctx: RouterContext)=>{
            const tag_name = ctx.params["tag_name"];
            const c = await tagController.getTagByName(tag_name);
            if (!c){
                sendError(404, "tags not found");
            }
            ctx.body = c;
            ctx.type = "json";
        });
    return router;
}